/*
 * Please cite:
 * Zen, G., Ricci, E.
 * Earth Mover’s Prototypes: a Convex Learning Approach for Discovering Activity Patterns in Dynamic Scenes.
 * IEEE Conference on Computer Vision and Pattern Recognition (CVPR), 2011.
 * http://disi.unitn.it/~zen/emd.html
 
 This file is part of EMP (Earth Mover's Prototypes).

 EMP is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 EMP is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with EMP.  If not, see <http://www.gnu.org/licenses/>.
 */


#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "param.h"

//------------------------------------------------------------------------------------------------------

void load_res(int* res, parameters& param);
void load_gt(int* gt, parameters& param);
double accuracy(int* res, int* gt, parameters& param);

/*

 */
int main(int argc, char** argv) {

    if (argc < 2) {
        fprintf(stderr, "\nUsage: %s [filename.config]\n\n", argv[0]);
        return-2;
    }
    // load config			
    char file_config[300];
    strcpy(file_config, argv[1]);
    parameters param;
    param.load_parameters_from_file(file_config);

    int* res = new int[param.N - 1];
    int* gt = new int[param.N - 1];

    load_res(res, param);
    load_gt(gt, param);

    double acc = 100.0*accuracy(res, gt, param);
    fprintf(stderr, "\naccuracy = %.2lf%% \n\n", acc);

    delete[] res;
    delete[] gt;

    return 0;
}
//------------------------------------------------------------------------------------------------------

void load_res(int* res, parameters& param) {
    
    char filename[300];
    sprintf(filename, "%s/%s", param.output_dir, param.file_res_clustering);
    FILE *pf = fopen(filename, "r");
    if (pf == NULL) {
        fprintf(stderr, "ERROR in load_res: Impossible to open file \'%s\' for reading\n", filename);
        exit(1);
    }
    int nclip = param.N - 1;
    for (int i = 0; i < nclip; ++i) {
        fscanf(pf, "%d", &(res[i]));
    }
    fclose(pf);
    fprintf(stderr, "\nclustering res:\n");
    for (int i = 0; i < nclip; ++i) {
        fprintf(stderr, "%d ", res[i]);
    }
}
//------------------------------------------------------------------------------------------------------

void load_gt(int* gt, parameters& param) {
    
    char filename[300];
    sprintf(filename, "%s/%s", param.output_dir, param.file_groundtruth);
    FILE *pf = fopen(filename, "r");
    if (pf == NULL) {
        fprintf(stderr, "ERROR in load_res: Impossible to open file \'%s\' for reading\n", filename);
        exit(1);
    }
    int nclip = param.N - 1;
    for (int i = 0; i < nclip; ++i) {
        fscanf(pf, "%d", &(gt[i]));
    }
    fclose(pf);
    fprintf(stderr, "\ngroundtruth:\n");
    for (int i = 0; i < nclip; ++i) {
        fprintf(stderr, "%d ", gt[i]);
    }
}
//------------------------------------------------------------------------------------------------------

double accuracy(int* res, int* gt, parameters& param){

    int nerror = 0;
    int nclip = param.N - 1;
    for(int i = 0; i < nclip; ++i){
        if(res[i] != gt[i])
            ++nerror;
    }
    double acc = (double) (nclip - nerror) / nclip;
    return acc;
}
//------------------------------------------------------------------------------------------------------
