/*
 * Please cite:
 * Zen, G., Ricci, E.
 * Earth Mover’s Prototypes: a Convex Learning Approach for Discovering Activity Patterns in Dynamic Scenes.
 * IEEE Conference on Computer Vision and Pattern Recognition (CVPR), 2011.
 * http://disi.unitn.it/~zen/emd.html
 
 This file is part of EMP (Earth Mover's Prototypes).

 EMP is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 EMP is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with EMP.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EMP_H
#define	EMP_H
#ifdef	__cplusplus
extern "C" {
#endif
#ifdef	__cplusplus
}
#endif

#include"param.h"

/* *************************************************************************************************** */

double dist_L1(double* vec1, double* vec2, int& D);

/* *************************************************************************************************** */

class EMP {
  
  int N; //#rows = number of clips
  int D; //#cols = histogram length
  int Np; //number of neighbors

  // input data
  double** data_matrix; //original data
  int* idx_cluster_sort; //atomic activities sorting
  int** adj_matrix; // clips adjacence matrix
  
  double gamma;

  // output res data
  double** clustered_data_matrix; //clustered data
  int* prototype_idx;
  int n_prot;

 public:

  EMP();
  EMP(parameters& param);
  ~EMP();

  // load/save
  int load_data_matrix_from_file(parameters& param);
  //void set_gamma(double& g) { gamma = g; };

  // emp solve
  int sort_data_matrix(parameters& param);
  int build_adjacence_matrix(parameters& param);
  int solve_convex(double& g, parameters& param);

  //print/save
  void print_adj_matrix();
  void save_results(parameters& param);
 
 protected:

  void init();
  void reset_out_data();
  void delete_data();

  // emp solve
  int load_sorting_from_file(char* filename);
  int solve_L1(double& g);
  int solve_EMDL1(double& g);
  int get_id_prototype();


};
/* *************************************************************************************************** */




#endif	/* EMP_H */

