/*
 * Please cite:
 * Zen, G., Ricci, E. 
 * Earth Mover’s Prototypes: a Convex Learning Approach for Discovering Activity Patterns in Dynamic Scenes.
 * IEEE Conference on Computer Vision and Pattern Recognition (CVPR), 2011.
 * http://disi.unitn.it/~zen/emd.html
 
 This file is part of EMP (Earth Mover's Prototypes).

 EMP is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 EMP is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with EMP.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>				
#include <stdlib.h>
#include <string.h>

#include <glpk.h>

//using namespace std;

#include "param.h"
#include "emp.h"

/* *************************************************************************************************** */

int main(int argc, char **argv) {

    if (argc < 2) {
        fprintf(stderr, "\nRun: %s [filename.config]\n\n", argv[0]);
        return-2;
    }

    //--- load config			
    char file_config[300];
    strcpy(file_config, argv[1]);
    //
    parameters param(file_config);
    fprintf(stderr, "\nparam loaded: N=%d, D=%d, Np=%d, gamma=%.5lf\n", param.N, param.D, param.Np, param.gamma);

    //--- init emp
    EMP emp(param);

    //--- load activities histograms
    emp.load_data_matrix_from_file(param);

    //--- sort atomic activities
    emp.sort_data_matrix(param);

    //--- find clips neighboring set
    emp.build_adjacence_matrix(param);

    //--- solve convex cluasterin
    emp.solve_convex(param.gamma, param);
 
    //--- print out results
    emp.save_results(param);

    return 0;
}

/* **************************************************************************************************************************************************************************************************** */
